@@ -1,4 +1,4 @@
-## ID: leverages.R, last updated 2023-10-21, F.Osorio
+## ID: leverages.R, last updated 2025-05-01, F.Osorio
 
 leverages <- function(model, ...) ## leverages (AKA "hatvalues")
 UseMethod("leverages")
@@ -6,6 +6,21 @@ UseMethod("leverages")
 leverages.lm <- function(model, infl = lm.influence(model, do.coef=FALSE), ...) ## for completeness only
 infl$hat
 
+leverages.nls <- function(model, ...)
+{ ## leverages for nonlinear regression
+  if (!inherits(model, "nls"))
+    stop("Use only with 'nls' objects")
+  obj <- model
+  F <- obj$m$gradient()
+  n <- nrow(F)
+  p <- ncol(F)
+
+  rs <- svd(F, nv = 0)
+  levs <- rowSums(rs$u^2)
+  names(levs) <- as.character(1:n)
+  levs
+}
+
 leverages.ols <- function(model, ...)
 { ## leverages for ordinary least squares
   if (!inherits(model, "ols"))
